# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/fastgs',
                'doc_host': 'https://restlessronin.github.io',
                'git_url': 'https://github.com/restlessronin/fastgs',
                'lib_path': 'fastgs'},
  'syms': { 'fastgs.multispectral': { 'fastgs.multispectral.BandInputs': ('multispectral.html#bandinputs', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.BandInputs._get_bands': ( 'multispectral.html#bandinputs._get_bands',
                                                                                      'fastgs/multispectral.py'),
                                      'fastgs.multispectral.BandInputs._get_index': ( 'multispectral.html#bandinputs._get_index',
                                                                                      'fastgs/multispectral.py'),
                                      'fastgs.multispectral.BandInputs.from_ids': ( 'multispectral.html#bandinputs.from_ids',
                                                                                    'fastgs/multispectral.py'),
                                      'fastgs.multispectral.BandInputs.get_bands_list': ( 'multispectral.html#bandinputs.get_bands_list',
                                                                                          'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData': ('multispectral.html#msdata', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.__init__': ( 'multispectral.html#msdata.__init__',
                                                                                'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData._load_image': ( 'multispectral.html#msdata._load_image',
                                                                                   'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.create_xform_block': ( 'multispectral.html#msdata.create_xform_block',
                                                                                          'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.load_image': ( 'multispectral.html#msdata.load_image',
                                                                                  'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.num_channels': ( 'multispectral.html#msdata.num_channels',
                                                                                    'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor': ('multispectral.html#msdescriptor', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.get_brgtX': ( 'multispectral.html#msdescriptor.get_brgtx',
                                                                                       'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.get_brgtX_list': ( 'multispectral.html#msdescriptor.get_brgtx_list',
                                                                                            'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.get_res_ids': ( 'multispectral.html#msdescriptor.get_res_ids',
                                                                                         'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSPipeline': ('multispectral.html#mspipeline', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSPipeline.__init__': ( 'multispectral.html#mspipeline.__init__',
                                                                                    'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSPipeline.create_data_block': ( 'multispectral.html#mspipeline.create_data_block',
                                                                                             'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSPipeline.create_unet_learner': ( 'multispectral.html#mspipeline.create_unet_learner',
                                                                                               'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData': ('multispectral.html#maskdata', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData.__init__': ( 'multispectral.html#maskdata.__init__',
                                                                                  'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData.create_xform_block': ( 'multispectral.html#maskdata.create_xform_block',
                                                                                            'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData.load_mask': ( 'multispectral.html#maskdata.load_mask',
                                                                                   'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData.num_channels': ( 'multispectral.html#maskdata.num_channels',
                                                                                      'fastgs/multispectral.py'),
                                      'fastgs.multispectral.createSentinel2Descriptor': ( 'multispectral.html#createsentinel2descriptor',
                                                                                          'fastgs/multispectral.py')},
            'fastgs.vision.core': { 'fastgs.vision.core.TensorImageMS': ('vision.core.html#tensorimagems', 'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._brighten': ( 'vision.core.html#tensorimagems._brighten',
                                                                                    'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._get_grid': ( 'vision.core.html#tensorimagems._get_grid',
                                                                                    'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._select_bands': ( 'vision.core.html#tensorimagems._select_bands',
                                                                                        'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._show_animation': ( 'vision.core.html#tensorimagems._show_animation',
                                                                                          'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._show_tiles': ( 'vision.core.html#tensorimagems._show_tiles',
                                                                                      'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS.num_images': ( 'vision.core.html#tensorimagems.num_images',
                                                                                     'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS.show': ( 'vision.core.html#tensorimagems.show',
                                                                               'fastgs/vision/core.py')},
            'fastgs.vision.data': { 'fastgs.vision.data._get_sample_ctxs': ('vision.data.html#_get_sample_ctxs', 'fastgs/vision/data.py'),
                                    'fastgs.vision.data._show_one_sample': ('vision.data.html#_show_one_sample', 'fastgs/vision/data.py'),
                                    'fastgs.vision.data.show_batch': ('vision.data.html#show_batch', 'fastgs/vision/data.py')},
            'fastgs.vision.learner': { 'fastgs.vision.learner._get_sample_ctxs': ( 'vision.learner.html#_get_sample_ctxs',
                                                                                   'fastgs/vision/learner.py'),
                                       'fastgs.vision.learner._show_one_result': ( 'vision.learner.html#_show_one_result',
                                                                                   'fastgs/vision/learner.py'),
                                       'fastgs.vision.learner.plot_top_losses': ( 'vision.learner.html#plot_top_losses',
                                                                                  'fastgs/vision/learner.py'),
                                       'fastgs.vision.learner.show_results': ( 'vision.learner.html#show_results',
                                                                               'fastgs/vision/learner.py')},
            'fastgs.vision.testio': { 'fastgs.vision.testio._filter_masked': ( 'vision.testio.html#_filter_masked',
                                                                               'fastgs/vision/testio.py'),
                                      'fastgs.vision.testio._get_input': ('vision.testio.html#_get_input', 'fastgs/vision/testio.py'),
                                      'fastgs.vision.testio._tile_img_name': ( 'vision.testio.html#_tile_img_name',
                                                                               'fastgs/vision/testio.py'),
                                      'fastgs.vision.testio._to_bin_seg': ('vision.testio.html#_to_bin_seg', 'fastgs/vision/testio.py'),
                                      'fastgs.vision.testio.get_channel_filenames': ( 'vision.testio.html#get_channel_filenames',
                                                                                      'fastgs/vision/testio.py'),
                                      'fastgs.vision.testio.read_chn_file': ('vision.testio.html#read_chn_file', 'fastgs/vision/testio.py'),
                                      'fastgs.vision.testio.read_mask_file': ( 'vision.testio.html#read_mask_file',
                                                                               'fastgs/vision/testio.py'),
                                      'fastgs.vision.testio.read_multichan_files': ( 'vision.testio.html#read_multichan_files',
                                                                                     'fastgs/vision/testio.py')}}}
